@@ -6,10 +6,6 @@
             href: 'about.html',
             name: Globalize.translate('TabAbout')
         },
-         {
-             href: 'log.html',
-             name: Globalize.translate('TabLogs')
-         },
          {
              href: 'supporterkey.html',
              name: Globalize.translate('TabEmbyPremiere')
